@@ -1,9 +1,7 @@
 __all__ = (
-    'DOMAIN_SPLIT_DELIMITER',
     'GLOBAL_DOMAIN_ARG',
     'MAX_CONCURRENT_EXPORT_TASKS',
 )
 
-DOMAIN_SPLIT_DELIMITER = ' '
 GLOBAL_DOMAIN_ARG = '-globalDomain'
 MAX_CONCURRENT_EXPORT_TASKS = 40
